@@ -24,15 +24,8 @@
 #include <string.h>
 #include <math.h>
 #include <unistd.h>
-
+#include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-lookup.h>
-#include <glade/glade.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #include "file-utils.h"
 #include "fr-stock.h"
 #include "gconf-utils.h"
@@ -44,20 +37,28 @@
 #include "main.h"
 
 
-#define GLADE_FILE "batch-add-files.glade"
 #define ARCHIVE_ICON_SIZE (48)
 #define DEFAULT_EXTENSION ".tar.gz"
 #define BAD_CHARS "/\\*"
 
+
 typedef struct {
 	FrWindow   *window;
-	GladeXML   *gui;
-
+	GtkBuilder *builder;
+	int        *supported_types;
+	
 	GtkWidget  *dialog;
 	GtkWidget  *a_add_to_entry;
 	GtkWidget  *a_location_filechooserbutton;
 	GtkWidget  *add_image;
 	GtkWidget  *a_archive_type_combo_box;
+	GtkWidget  *a_other_options_expander;
+	GtkWidget  *a_password_entry;
+	GtkWidget  *a_password_label;
+	GtkWidget  *a_encrypt_header_checkbutton;
+	GtkWidget  *a_volume_checkbutton;
+	GtkWidget  *a_volume_spinbutton;
+	GtkWidget  *a_volume_box;
 
 	GList      *file_list;
 	gboolean    add_clicked;
@@ -66,39 +67,78 @@ typedef struct {
 } DialogData;
 
 
+static const char *
+get_ext (DialogData *data)
+{
+	int idx;
+
+	idx = gtk_combo_box_get_active (GTK_COMBO_BOX (data->a_archive_type_combo_box));
+
+	return mime_type_desc[data->supported_types[idx]].default_ext;
+}
+
+
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget,
 	    DialogData *data)
 {
+	eel_gconf_set_string (PREF_BATCH_ADD_DEFAULT_EXTENSION, get_ext (data));
+	/*eel_gconf_set_boolean (PREF_BATCH_OTHER_OPTIONS, data->add_clicked ? FALSE : gtk_expander_get_expanded (GTK_EXPANDER (data->a_other_options_expander)));*/
+	eel_gconf_set_boolean (PREF_ENCRYPT_HEADER, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->a_encrypt_header_checkbutton)));
+	
 	if (! data->add_clicked) {
 		fr_window_pop_message (data->window);
 		fr_window_stop_batch (data->window);
 	}
 
-	g_object_unref (data->gui);
+	g_object_unref (data->builder);
 	g_free (data);
 }
 
 
-static const char *
-get_ext (DialogData *data)
+static void
+set_archive_options (DialogData *data)
 {
-	FRFileType *save_type_list;
-	int         idx;
-
-	if (data->single_file)
-		save_type_list = single_file_save_type;
-	else
-		save_type_list =  save_type;
+	int idx;
 
 	idx = gtk_combo_box_get_active (GTK_COMBO_BOX (data->a_archive_type_combo_box));
+	if (mime_type_desc[data->supported_types[idx]].capabilities & FR_COMMAND_CAN_ENCRYPT) {
+		char *pwd;
 
-	return file_type_desc[save_type_list[idx]].ext;
+		pwd = (char*) gtk_entry_get_text (GTK_ENTRY (data->a_password_entry));
+		if (pwd != NULL) {
+			pwd = g_strstrip (pwd);
+			if (strcmp (pwd, "") != 0) {
+				fr_window_set_password (data->window, pwd);
+				if (mime_type_desc[data->supported_types[idx]].capabilities & FR_COMMAND_CAN_ENCRYPT_HEADER)
+					fr_window_set_encrypt_header (data->window, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->a_encrypt_header_checkbutton)));
+			}
+		}
+	}
+
+	if ((mime_type_desc[data->supported_types[idx]].capabilities & FR_COMMAND_CAN_CREATE_VOLUMES)
+	    && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->a_volume_checkbutton)))
+	{
+		double value;
+		int    size;
+
+		value = gtk_spin_button_get_value (GTK_SPIN_BUTTON (data->a_volume_spinbutton));
+		size = floor (value * MEGABYTE);
+		eel_gconf_set_integer (PREF_BATCH_VOLUME_SIZE, size);
+		fr_window_set_volume_size (data->window, (guint) size);
+	}
+}
+
+
+static void
+help_clicked_cb (GtkWidget  *widget,
+		 DialogData *data)
+{
+	show_help_dialog (GTK_WINDOW (data->dialog), "file-roller-fmgr-add");
 }
 
 
-/* called when the "add" button is pressed. */
 static void
 add_clicked_cb (GtkWidget  *widget,
 		DialogData *data)
@@ -110,12 +150,13 @@ add_clicked_cb (GtkWidget  *widget,
 	char       *tmp;
 	const char *archive_ext;
 	gboolean    do_not_add = FALSE;
+	GError     *error = NULL;
 
 	data->add_clicked = TRUE;
 
 	/* Collect data */
 
-	archive_name = gnome_vfs_escape_string (gtk_entry_get_text (GTK_ENTRY (data->a_add_to_entry)));
+	archive_name = g_uri_escape_string (gtk_entry_get_text (GTK_ENTRY (data->a_add_to_entry)), NULL, FALSE);
 
 	/* Check whether the user entered a valid archive name. */
 
@@ -126,6 +167,7 @@ add_clicked_cb (GtkWidget  *widget,
 					   GTK_DIALOG_DESTROY_WITH_PARENT,
 					   NULL,
 					   _("Could not create the archive"),
+					   "%s",
 					   _("You have to specify an archive name."));
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -141,9 +183,9 @@ add_clicked_cb (GtkWidget  *widget,
 					   GTK_DIALOG_DESTROY_WITH_PARENT,
 					   NULL,
 					   _("Could not create the archive"),
-					   _("The name \"%s\" is not valid because it cannot contain the characters: %s\n\n%s"), 
-					   utf8_name, 
-					   BAD_CHARS, 
+					   _("The name \"%s\" is not valid because it cannot contain the characters: %s\n\n%s"),
+					   utf8_name,
+					   BAD_CHARS,
 					   _("Please use a different name."));
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -156,7 +198,12 @@ add_clicked_cb (GtkWidget  *widget,
 
 	/* Check directory existence. */
 
-	archive_dir = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (data->a_location_filechooserbutton));
+	archive_dir = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->a_location_filechooserbutton));
+	if (archive_dir == NULL) {
+		g_free (archive_dir);
+		g_free (archive_name);
+		return;
+	}
 
 	if (! check_permissions (archive_dir, R_OK|W_OK|X_OK)) {
 		GtkWidget  *d;
@@ -165,6 +212,7 @@ add_clicked_cb (GtkWidget  *widget,
 					   GTK_DIALOG_DESTROY_WITH_PARENT,
 					   NULL,
 					   _("Could not create the archive"),
+					   "%s",
 					   _("You don't have the right permissions to create an archive in the destination folder."));
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -174,7 +222,7 @@ add_clicked_cb (GtkWidget  *widget,
 		return;
 	}
 
-	if (! path_is_dir (archive_dir)) {
+	if (! uri_is_dir (archive_dir)) {
 		GtkWidget *d;
 		int        r;
 		char      *folder_name;
@@ -202,7 +250,7 @@ add_clicked_cb (GtkWidget  *widget,
 		do_not_add = (r != GTK_RESPONSE_YES);
 	}
 
-	if (! do_not_add && ! ensure_dir_exists (archive_dir, 0755)) {
+	if (! do_not_add && ! ensure_dir_exists (archive_dir, 0755, &error)) {
 		GtkWidget  *d;
 
 		d = _gtk_error_dialog_new (GTK_WINDOW (window),
@@ -210,10 +258,11 @@ add_clicked_cb (GtkWidget  *widget,
 					   NULL,
 					   _("Could not create the archive"),
 					   _("Could not create the destination folder: %s."),
-					   gnome_vfs_result_to_string (gnome_vfs_result_from_errno ()));
+					   error->message);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
 
+		g_error_free (error);
 		g_free (archive_dir);
 		g_free (archive_name);
 		return;
@@ -246,15 +295,15 @@ add_clicked_cb (GtkWidget  *widget,
 	archive_name = g_strconcat (tmp, archive_ext, NULL);
 	g_free (tmp);
 	archive_file = g_strconcat (archive_dir, "/", archive_name, NULL);
-	eel_gconf_set_string (PREF_BATCH_ADD_DEFAULT_EXTENSION, archive_ext);
 
-	if (path_is_dir (archive_file)) {
+	if (uri_is_dir (archive_file)) {
 		GtkWidget  *d;
 
 		d = _gtk_error_dialog_new (GTK_WINDOW (window),
 					   GTK_DIALOG_DESTROY_WITH_PARENT,
 					   NULL,
 					   _("Could not create the archive"),
+					   "%s",
 					   _("You have to specify an archive name."));
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -266,7 +315,7 @@ add_clicked_cb (GtkWidget  *widget,
 		return;
 	}
 
-	if (path_is_file (archive_file)) {
+	if (uri_exists (archive_file)) {
 		GtkWidget *d;
 		int        r;
 
@@ -283,8 +332,21 @@ add_clicked_cb (GtkWidget  *widget,
 		r = gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
 
-		if (r == GTK_RESPONSE_YES)
-			gnome_vfs_unlink (archive_file);
+		if (r == GTK_RESPONSE_YES) {
+			GFile  *file;
+			GError *err = NULL;
+
+			/* FIXME: convert this code in a function in file-utils.c */
+			file = g_file_new_for_uri (archive_file);
+			g_file_delete (file, NULL, &err);
+			if (err != NULL) {
+				g_warning ("Failed to delete file %s: %s",
+					   archive_file,
+					   err->message);
+				g_clear_error (&err);
+			}
+			g_object_unref (file);
+		}
 		else {
 			g_free (archive_name);
 			g_free (archive_dir);
@@ -292,13 +354,10 @@ add_clicked_cb (GtkWidget  *widget,
 			return;
 		}
 	}
-
+	set_archive_options (data);
 	gtk_widget_destroy (data->dialog);
 
-	if (! path_is_file (archive_file))
-		fr_window_archive_new (window, archive_file);
-	else
-		fr_window_archive_open (window, archive_file, GTK_WINDOW (window));
+	fr_window_archive_new (window, archive_file);
 
 	g_free (archive_name);
 	g_free (archive_dir);
@@ -306,37 +365,37 @@ add_clicked_cb (GtkWidget  *widget,
 }
 
 
-static GdkPixbuf *
-get_pixbuf_from_mime_type (const char *mime_type,
-			   int         icon_size)
+static void
+update_sensitivity_for_mime_type (DialogData *data,
+				  const char *mime_type)
 {
-	GtkIconTheme *icon_theme;
-	char         *icon_name = NULL;
-	GdkPixbuf    *icon = NULL;
+	int i;
 
-	icon_theme = gtk_icon_theme_get_default ();
+	if (mime_type == NULL) {
+		gtk_widget_set_sensitive (data->a_password_entry, FALSE);
+		gtk_widget_set_sensitive (data->a_password_label, FALSE);
+		gtk_widget_set_sensitive (data->a_encrypt_header_checkbutton, FALSE);
+		gtk_widget_set_sensitive (data->a_volume_box, FALSE);
+		return;
+	}
 
-	if (icon_theme == NULL)
-		return NULL;
+	for (i = 0; mime_type_desc[i].mime_type != NULL; i++) {
+		if (strcmp (mime_type_desc[i].mime_type, mime_type) == 0) {
+			gboolean sensitive;
 
-	icon_name = gnome_icon_lookup (icon_theme,
-				       NULL,
-				       NULL,
-				       NULL,
-				       NULL,
-				       mime_type,
-				       GNOME_ICON_LOOKUP_FLAGS_NONE,
-				       NULL);
+			sensitive = mime_type_desc[i].capabilities & FR_COMMAND_CAN_ENCRYPT;
+			gtk_widget_set_sensitive (data->a_password_entry, sensitive);
+			gtk_widget_set_sensitive (data->a_password_label, sensitive);
 
-	if (icon_name != NULL) 
-		icon = gtk_icon_theme_load_icon (icon_theme,
-						 icon_name,
-						 icon_size,
-						 0,
-						 NULL);
+			sensitive = mime_type_desc[i].capabilities & FR_COMMAND_CAN_ENCRYPT_HEADER;
+			gtk_widget_set_sensitive (data->a_encrypt_header_checkbutton, sensitive);
 
-	g_free (icon_name);
-	return icon;
+			sensitive = mime_type_desc[i].capabilities & FR_COMMAND_CAN_CREATE_VOLUMES;
+			gtk_widget_set_sensitive (data->a_volume_box, sensitive);
+
+			break;
+		}
+	}
 }
 
 
@@ -344,17 +403,13 @@ static void
 archive_type_combo_box_changed_cb (GtkComboBox *combo_box,
 				   DialogData  *data)
 {
-	FRFileType *save_type_list;
 	const char *mime_type;
 	int         idx = gtk_combo_box_get_active (combo_box);
 
-	if (data->single_file)
-		save_type_list = single_file_save_type;
-	else
-		save_type_list =  save_type;
-	mime_type = file_type_desc[save_type_list[idx]].mime_type;
+	mime_type = mime_type_desc[data->supported_types[idx]].mime_type;
 
-	gtk_image_set_from_pixbuf (GTK_IMAGE (data->add_image), get_pixbuf_from_mime_type (mime_type, ARCHIVE_ICON_SIZE));
+	gtk_image_set_from_pixbuf (GTK_IMAGE (data->add_image), get_mime_type_pixbuf (mime_type, ARCHIVE_ICON_SIZE, NULL));
+	update_sensitivity_for_mime_type (data, mime_type);
 }
 
 
@@ -362,22 +417,16 @@ static void
 update_archive_type_combo_box_from_ext (DialogData  *data,
 					const char  *ext)
 {
-	FRFileType *save_type_list;
-	int         idx = 0;
-	int         i;
+	int idx = 0;
+	int i;
 
 	if (ext == NULL) {
 		gtk_combo_box_set_active (GTK_COMBO_BOX (data->a_archive_type_combo_box), 0);
 		return;
 	}
 
-	if (data->single_file)
-		save_type_list = single_file_save_type;
-	else
-		save_type_list =  save_type;
-
-	for (i = 0; save_type_list[i] != FR_FILE_TYPE_NULL; i++)
-		if (strcmp (ext, file_type_desc[save_type_list[i]].ext) == 0) {
+	for (i = 0; data->supported_types[i] != -1; i++)
+		if (strcmp (ext, mime_type_desc[data->supported_types[i]].default_ext) == 0) {
 			idx = i;
 			break;
 		}
@@ -386,71 +435,119 @@ update_archive_type_combo_box_from_ext (DialogData  *data,
 }
 
 
+static void
+update_sensitivity (DialogData *data)
+{
+	const char *password;
+	gboolean    void_password;
+
+	password = gtk_entry_get_text (GTK_ENTRY (data->a_password_entry));
+	void_password = (password == NULL) || (strcmp (password, "") == 0);
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (data->a_encrypt_header_checkbutton), void_password);
+	/*gtk_widget_set_sensitive (GTK_WIDGET (data->a_encrypt_header_checkbutton), ! void_password);*/
+	gtk_widget_set_sensitive (data->a_volume_spinbutton, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->a_volume_checkbutton)));
+}
+
+
+static void
+password_entry_changed_cb (GtkEditable *editable,
+			   gpointer     user_data)
+{
+	update_sensitivity ((DialogData *) user_data);
+}
+
+
+static void
+volume_toggled_cb (GtkToggleButton *toggle_button,
+		   gpointer         user_data)
+{
+	update_sensitivity ((DialogData *) user_data);
+}
+
+
 void
 dlg_batch_add_files (FrWindow *window,
 		     GList    *file_list)
 {
-	DialogData *data;
-	GtkWidget  *cancel_button;
-	GtkWidget  *add_button;
-	GtkWidget  *a_archive_type_box;
-	char       *automatic_name = NULL;
-	char       *default_ext;
-	const char *first_filename;
-	char       *parent;
-	int         i;
-	FRFileType *save_type_list;
+	DialogData   *data;
+	GtkWidget    *cancel_button;
+	GtkWidget    *help_button;
+	GtkWidget    *add_button;
+	GtkWidget    *a_archive_type_box;
+	GtkSizeGroup *size_group;
+	char         *automatic_name = NULL;
+	char         *default_ext;
+	const char   *first_filename;
+	char         *parent;
+	int           i;
 
 	if (file_list == NULL)
 		return;
 
 	data = g_new0 (DialogData, 1);
 
-	data->gui = glade_xml_new (GLADEDIR "/" GLADE_FILE , NULL, NULL);
-	if (data->gui == NULL) {
-		g_warning ("Could not find " GLADE_FILE "\n");
+	data->builder = _gtk_builder_new_from_file ("batch-add-files.ui");
+	if (data->builder == NULL) {
+		g_free (data);
 		return;
 	}
 
 	data->window = window;
 	data->file_list = file_list;
-	data->single_file = ((file_list->next == NULL) && path_is_file ((char*) file_list->data));
+	data->single_file = ((file_list->next == NULL) && uri_is_file ((char*) file_list->data));
 	data->add_clicked = FALSE;
 
 	/* Get the widgets. */
 
-	data->dialog = glade_xml_get_widget (data->gui, "batch_add_files_dialog");
-	data->a_add_to_entry = glade_xml_get_widget (data->gui, "a_add_to_entry");
-	data->a_location_filechooserbutton = glade_xml_get_widget (data->gui, "a_location_filechooserbutton");
+	data->dialog = _gtk_builder_get_widget (data->builder, "batch_add_files_dialog");
+	data->a_add_to_entry = _gtk_builder_get_widget (data->builder, "a_add_to_entry");
+	data->a_location_filechooserbutton = _gtk_builder_get_widget (data->builder, "a_location_filechooserbutton");
+	data->a_password_entry = _gtk_builder_get_widget (data->builder, "a_password_entry");
+	data->a_password_label = _gtk_builder_get_widget (data->builder, "a_password_label");
+	data->a_other_options_expander = _gtk_builder_get_widget (data->builder, "a_other_options_expander");
+	data->a_encrypt_header_checkbutton = _gtk_builder_get_widget (data->builder, "a_encrypt_header_checkbutton");
 
-	add_button = glade_xml_get_widget (data->gui, "a_add_button");
-	cancel_button = glade_xml_get_widget (data->gui, "a_cancel_button");
-	a_archive_type_box = glade_xml_get_widget (data->gui, "a_archive_type_box");
+	data->a_volume_checkbutton = _gtk_builder_get_widget (data->builder, "a_volume_checkbutton");
+	data->a_volume_spinbutton = _gtk_builder_get_widget (data->builder, "a_volume_spinbutton");
+	data->a_volume_box = _gtk_builder_get_widget (data->builder, "a_volume_box");
 
-	data->add_image = glade_xml_get_widget (data->gui, "a_add_image");
+	add_button = _gtk_builder_get_widget (data->builder, "a_add_button");
+	cancel_button = _gtk_builder_get_widget (data->builder, "a_cancel_button");
+	help_button = _gtk_builder_get_widget (data->builder, "a_help_button");
+	a_archive_type_box = _gtk_builder_get_widget (data->builder, "a_archive_type_box");
+
+	data->add_image = _gtk_builder_get_widget (data->builder, "a_add_image");
 
 	/* Set widgets data. */
 
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	gtk_size_group_add_widget (size_group, _gtk_builder_get_widget (data->builder, "a_archive_label"));
+	gtk_size_group_add_widget (size_group, _gtk_builder_get_widget (data->builder, "a_location_label"));
+	gtk_size_group_add_widget (size_group, _gtk_builder_get_widget (data->builder, "a_password_label"));
+
 	gtk_button_set_use_stock (GTK_BUTTON (add_button), TRUE);
 	gtk_button_set_label (GTK_BUTTON (add_button), FR_STOCK_CREATE_ARCHIVE);
-	
+	gtk_expander_set_expanded (GTK_EXPANDER (data->a_other_options_expander), FALSE /*eel_gconf_get_boolean (PREF_BATCH_OTHER_OPTIONS, FALSE)*/);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->a_encrypt_header_checkbutton), eel_gconf_get_boolean (PREF_ENCRYPT_HEADER, FALSE));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->a_volume_spinbutton), (double) eel_gconf_get_integer (PREF_BATCH_VOLUME_SIZE, 0) / MEGABYTE);
+
 	first_filename = (char*) file_list->data;
 	parent = remove_level_from_path (first_filename);
 
 	if (file_list->next == NULL)
-		automatic_name = gnome_vfs_unescape_string (file_name_from_path ((char*) file_list->data), "");
+		automatic_name = g_uri_unescape_string (file_name_from_path ((char*) file_list->data), NULL);
 	else {
-		automatic_name = gnome_vfs_unescape_string (file_name_from_path (parent), "");
+		automatic_name = g_uri_unescape_string (file_name_from_path (parent), NULL);
 		if ((automatic_name == NULL) || (automatic_name[0] == '\0')) {
 			g_free (automatic_name);
-			automatic_name = gnome_vfs_unescape_string (file_name_from_path (first_filename), "");
+			automatic_name = g_uri_unescape_string (file_name_from_path (first_filename), NULL);
 		}
 	}
 
 	_gtk_entry_set_filename_text (GTK_ENTRY (data->a_add_to_entry), automatic_name);
 	g_free (automatic_name);
 
-	if (check_permissions (parent, R_OK|W_OK|X_OK))
+	if (check_permissions (parent, R_OK | W_OK))
 		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->a_location_filechooserbutton), parent);
 	else
 		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (data->a_location_filechooserbutton), get_home_uri ());
@@ -460,14 +557,14 @@ dlg_batch_add_files (FrWindow *window,
 
 	data->a_archive_type_combo_box = gtk_combo_box_new_text ();
 	if (data->single_file)
-		save_type_list = single_file_save_type;
+		data->supported_types = single_file_save_type;
 	else
-		save_type_list = save_type;
-
-	for (i = 0; save_type_list[i] != FR_FILE_TYPE_NULL; i++) {
+		data->supported_types = save_type;
+	sort_mime_types_by_extension (data->supported_types);
+	
+	for (i = 0; data->supported_types[i] != -1; i++)
 		gtk_combo_box_append_text (GTK_COMBO_BOX (data->a_archive_type_combo_box),
-					   file_type_desc[save_type_list[i]].ext);
-	}
+					   mime_type_desc[data->supported_types[i]].default_ext);
 
 	gtk_box_pack_start (GTK_BOX (a_archive_type_box), data->a_archive_type_combo_box, TRUE, TRUE, 0);
 	gtk_widget_show_all (a_archive_type_box);
@@ -486,10 +583,22 @@ dlg_batch_add_files (FrWindow *window,
 			  "clicked",
 			  G_CALLBACK (add_clicked_cb),
 			  data);
+	g_signal_connect (G_OBJECT (help_button),
+			  "clicked",
+			  G_CALLBACK (help_clicked_cb),
+			  data);
 	g_signal_connect (G_OBJECT (data->a_archive_type_combo_box),
 			  "changed",
 			  G_CALLBACK (archive_type_combo_box_changed_cb),
 			  data);
+	g_signal_connect (G_OBJECT (data->a_password_entry),
+			  "changed",
+			  G_CALLBACK (password_entry_changed_cb),
+			  data);
+	g_signal_connect (G_OBJECT (data->a_volume_checkbutton),
+			  "toggled",
+			  G_CALLBACK (volume_toggled_cb),
+			  data);
 
 	/* Run dialog. */
 
@@ -501,6 +610,8 @@ dlg_batch_add_files (FrWindow *window,
 	gtk_editable_select_region (GTK_EDITABLE (data->a_add_to_entry),
 				    0, -1);
 
+	update_sensitivity (data);
+
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_window_present (GTK_WINDOW (data->dialog));
 }
