@@ -165,7 +165,7 @@ get_last_field_zoo (char *line)
 		field = eat_spaces (field);
 		field = strchr (field, ' ');
 		field = eat_spaces (field);
-	} else 
+	} else
 		field = eat_spaces (field);
 
 	return field;
@@ -173,7 +173,7 @@ get_last_field_zoo (char *line)
 
 
 static void
-process_zoo_line (char     *line, 
+process_zoo_line (char     *line,
 		  gpointer  data)
 {
 	FileData    *fdata;
@@ -220,12 +220,9 @@ process_zoo_line (char     *line,
 
 
 static void
-fr_command_zoo_list (FrCommand  *zoo_comm,
-		     const char *password)
+fr_command_zoo_list (FrCommand  *zoo_comm)
 {
-	fr_process_set_out_line_func (FR_COMMAND (zoo_comm)->process,
-				      process_zoo_line,
-				      zoo_comm);
+	fr_process_set_out_line_func (zoo_comm->process, process_zoo_line, zoo_comm);
 
 	fr_process_begin_command (zoo_comm->process, "zoo");
 	fr_process_add_arg (zoo_comm->process, "lq");
@@ -237,12 +234,11 @@ fr_command_zoo_list (FrCommand  *zoo_comm,
 
 static void
 fr_command_zoo_add (FrCommand     *comm,
+		    const char    *from_file,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
-		    gboolean       recursive,
-		    const char    *password,
-		    FrCompression  compression)
+		    gboolean       recursive)
 {
 	GList        *scan;
 
@@ -252,7 +248,7 @@ fr_command_zoo_add (FrCommand     *comm,
 
 	fr_process_set_working_dir (comm->process, base_dir);
 
-	if (update) 
+	if (update)
 		fr_process_add_arg (comm->process, "auP");
 	else
 		fr_process_add_arg (comm->process, "aP");
@@ -267,6 +263,7 @@ fr_command_zoo_add (FrCommand     *comm,
 
 static void
 fr_command_zoo_delete (FrCommand *comm,
+		       const char  *from_file,
 		       GList     *file_list)
 {
 	GList        *scan;
@@ -285,12 +282,12 @@ fr_command_zoo_delete (FrCommand *comm,
 
 static void
 fr_command_zoo_extract (FrCommand  *comm,
+			const char  *from_file,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
 			gboolean    skip_older,
-			gboolean    junk_paths,
-			const char *password)
+			gboolean    junk_paths)
 {
 	GList *scan;
 
@@ -314,8 +311,7 @@ fr_command_zoo_extract (FrCommand  *comm,
 
 
 static void
-fr_command_zoo_test (FrCommand   *comm,
-		     const char  *password)
+fr_command_zoo_test (FrCommand   *comm)
 {
 	fr_process_begin_command (comm->process, "zoo");
 	fr_process_add_arg (comm->process, "-test");
@@ -324,19 +320,31 @@ fr_command_zoo_test (FrCommand   *comm,
 }
 
 
-static void
-fr_command_zoo_set_mime_type (FrCommand  *comm,
-			      const char *mime_type)
+const char *zoo_mime_type[] = { "application/x-zoo", NULL };
+
+
+const char **
+fr_command_zoo_get_mime_types (FrCommand *comm)
 {
-	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
-	
-	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("zoo")) 
-		comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
+	return zoo_mime_type;
 }
 
 
-static void 
+FrCommandCap
+fr_command_zoo_get_capabilities (FrCommand  *comm,
+			         const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("zoo"))
+		capabilities |= FR_COMMAND_CAN_READ_WRITE;
+
+	return capabilities;
+}
+
+
+static void
 fr_command_zoo_class_init (FrCommandZooClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
@@ -347,20 +355,21 @@ fr_command_zoo_class_init (FrCommandZooClass *class)
 
 	gobject_class->finalize = fr_command_zoo_finalize;
 
-        afc->list          = fr_command_zoo_list;
-	afc->add           = fr_command_zoo_add;
-	afc->delete        = fr_command_zoo_delete;
-	afc->extract       = fr_command_zoo_extract;
-	afc->test          = fr_command_zoo_test;
-	afc->set_mime_type = fr_command_zoo_set_mime_type;
+        afc->list             = fr_command_zoo_list;
+	afc->add              = fr_command_zoo_add;
+	afc->delete           = fr_command_zoo_delete;
+	afc->extract          = fr_command_zoo_extract;
+	afc->test             = fr_command_zoo_test;
+	afc->get_mime_types   = fr_command_zoo_get_mime_types;
+	afc->get_capabilities = fr_command_zoo_get_capabilities;
 }
 
- 
-static void 
+
+static void
 fr_command_zoo_init (FrCommand *comm)
 {
 	comm->propAddCanUpdate             = TRUE;
-	comm->propAddCanReplace            = FALSE; 
+	comm->propAddCanReplace            = FALSE;
 	comm->propExtractCanAvoidOverwrite = FALSE;
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = FALSE;
@@ -369,7 +378,7 @@ fr_command_zoo_init (FrCommand *comm)
 }
 
 
-static void 
+static void
 fr_command_zoo_finalize (GObject *object)
 {
         g_return_if_fail (object != NULL);
