@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "../../src/typedefs.h" */
-#include "../../src/typedefs.h"
+/* enumerations from "/home/paolo/workspace/file-roller/src/typedefs.h" */
+#include "/home/paolo/workspace/file-roller/src/typedefs.h"
 GType
 fr_compression_get_type (void)
 {
