@@ -101,6 +101,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-gzip",                 ".gz",       NULL, 0 },
 	{ "application/x-java-archive",         ".jar",      N_("Jar (.jar)"), 0 },
 	{ "application/x-lha",                  ".lzh",      N_("Lha (.lzh)"), 0 },
+	{ "application/x-lzip",                 ".lz",       NULL, 0 },
+	{ "application/x-lzip-compressed-tar",  ".tar.lz",   N_("Tar compressed with lzip (.tar.lz)"), 0 },
 	{ "application/x-lzma",                 ".lzma",     NULL, 0 },
 	{ "application/x-lzma-compressed-tar",  ".tar.lzma", N_("Tar compressed with lzma (.tar.lzma)"), 0 },
 	{ "application/x-lzop",                 ".lzo",      NULL, 0 },
@@ -112,6 +114,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-tarz",                 ".tar.Z",    N_("Tar compressed with compress (.tar.Z)"), 0 },
 	{ "application/x-stuffit",              ".sit",      NULL, 0 },
 	{ "application/x-war",                  ".war",      N_("War (.war)"), 0 },
+	{ "application/x-xz",                   ".xz",       N_("Xz (.xz)"), 0 },
+	{ "application/x-xz-compressed-tar",    ".tar.xz",   N_("Tar compressed with xz (.tar.xz)"), 0 },
 	{ "application/x-zoo",                  ".zoo",      N_("Zoo (.zoo)"), 0 },
 	{ "application/zip",                    ".zip",      N_("Zip (.zip)"), 0 },
 	{ NULL, NULL, NULL, 0 }
@@ -138,6 +142,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".jar", "application/x-java-archive" },
 	{ ".lha", "application/x-lha" },
 	{ ".lzh", "application/x-lha" },
+	{ ".lz", "application/x-lzip" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
 	{ ".rar", "application/x-rar" },
@@ -148,17 +153,22 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.bz", "application/x-bzip-compressed-tar" },
 	{ ".tar.bz2", "application/x-bzip-compressed-tar" },
 	{ ".tar.gz", "application/x-compressed-tar" },
+	{ ".tar.lz", "application/x-lzip-compressed-tar" },
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
 	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
 	{ ".tar.7z", "application/x-7z-compressed-tar" },
+	{ ".tar.xz", "application/x-xz-compressed-tar" },
 	{ ".tar.Z", "application/x-tarz" },
 	{ ".taz", "application/x-tarz" },
 	{ ".tbz", "application/x-bzip-compressed-tar" },
 	{ ".tbz2", "application/x-bzip-compressed-tar" },
 	{ ".tgz", "application/x-compressed-tar" },
+	{ ".txz", "application/x-xz-compressed-tar" },
+	{ ".tlz", "application/x-lzip-compressed-tar" },
 	{ ".tzma", "application/x-lzma-compressed-tar" },
 	{ ".tzo", "application/x-lzop-compressed-tar" },
 	{ ".war", "application/x-war" },
+	{ ".xz", "application/x-xz" },
 	{ ".z", "application/x-gzip" },
 	{ ".Z", "application/x-compress" },
 	{ ".zip", "application/zip" },
@@ -188,7 +198,7 @@ static const GOptionEntry options[] = {
 	  NULL },
 
 	{ "extract-here", 'h', 0, G_OPTION_ARG_NONE, &extract_here,
-	  N_("Extract archives using the archive name as destination folder and quit the program"),
+	  N_("Extract the contents of the archives in the archive folder and quit the program"),
 	  NULL },
 
 	{ "default-dir", '\0', 0, G_OPTION_ARG_STRING, &default_url,
@@ -669,23 +679,23 @@ add_if_non_present (int *a,
 
 
 static int
-cmp_mime_type_by_extension (const void *p1, 
+cmp_mime_type_by_extension (const void *p1,
 			    const void *p2)
 {
 	int i1 = * (int*) p1;
 	int i2 = * (int*) p2;
-	
+
 	return strcmp (mime_type_desc[i1].default_ext, mime_type_desc[i2].default_ext);
 }
 
 
 static int
-cmp_mime_type_by_description (const void *p1, 
+cmp_mime_type_by_description (const void *p1,
 			      const void *p2)
 {
 	int i1 = * (int*) p1;
 	int i2 = * (int*) p2;
-	
+
 	return g_utf8_collate (_(mime_type_desc[i1].name), _(mime_type_desc[i2].name));
 }
 
@@ -696,8 +706,8 @@ sort_mime_types (int *a,
 {
 	int n = 0;
 
-	while (a[n] != -1) 
-		n++;		
+	while (a[n] != -1)
+		n++;
 	qsort (a, n, sizeof (int), compar);
 }
 
@@ -763,11 +773,11 @@ get_uri_from_command_line (const char *path)
 {
 	GFile *file;
 	char  *uri;
-		
+
 	file = g_file_new_for_commandline_arg (path);
 	uri = g_file_get_uri (file);
 	g_object_unref (file);
-	
+
 	return uri;
 }
 
